// -----------------------------------------------------------------------------
// Copyright 2009-2012 Patrick Näf (herzbube@herzbube.ch)
//
// This file is part of the dgsmonX project.
//
// dgsmonX is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// dgsmonX is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with dgsmonX. If not, see <http://www.gnu.org/licenses/>.
// -----------------------------------------------------------------------------


// Forward declarations
@class DGSMonXServerQuickStatus;
@class DGSMonXServer;


// -----------------------------------------------------------------------------
/// @brief The DGSMonXServerQuickStatusDelegate protocol must be implemented by
/// the delegate of DGSMonXServerQuickStatus.
// -----------------------------------------------------------------------------
@protocol DGSMonXServerQuickStatusDelegate
- (void) quickStatusSucceeded:(DGSMonXServerQuickStatus*)serverQuickStatus numberOfGames:(int)numberOfGames;
- (void) quickStatusFailed:(DGSMonXServerQuickStatus*)serverQuickStatus errorDetails:(NSString*)errorDetails;
- (void) quickStatusCancelled:(DGSMonXServerQuickStatus*)serverQuickStatus;
@end


// -----------------------------------------------------------------------------
/// @brief The DGSMonXServerQuickStatus class uses Cocoa's URL loading system to
/// request the quick_status.php page from the DGS server specified on
/// construction.
// -----------------------------------------------------------------------------
@interface DGSMonXServerQuickStatus : NSObject
{
@private
  DGSMonXServer* server;
  id<DGSMonXServerQuickStatusDelegate> delegate;
  NSURLConnection* connection;
  NSURLResponse* receivedResponse;
  NSMutableData* receivedData;
}

- (id) initWithServer:(DGSMonXServer*)aServer delegate:(id<DGSMonXServerQuickStatusDelegate>)aDelegate;
- (void) cancel;

/// @brief The Dragon Go Server to perform the game state check on.
@property(nonatomic, assign) DGSMonXServer* server;
/// @brief The delegate that will be informed when the login process has
/// finished.
@property(nonatomic, assign) id<DGSMonXServerQuickStatusDelegate> delegate;

@end
